summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_view.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /chalk/ui/kis_view.cc
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'chalk/ui/kis_view.cc')
-rw-r--r--chalk/ui/kis_view.cc34
1 files changed, 17 insertions, 17 deletions
diff --git a/chalk/ui/kis_view.cc b/chalk/ui/kis_view.cc
index eecfa659..629072ff 100644
--- a/chalk/ui/kis_view.cc
+++ b/chalk/ui/kis_view.cc
@@ -494,11 +494,11 @@ void KisView::setupRulers()
void KisView::updateStatusBarZoomLabel ()
{
if (zoom() < 1 - EPSILON) {
- m_statusBarZoomLabel->setText(i18n("Zoom %1%").tqarg(zoom() * 100, 0, 'g', 4));
+ m_statusBarZoomLabel->setText(i18n("Zoom %1%").arg(zoom() * 100, 0, 'g', 4));
} else {
- m_statusBarZoomLabel->setText(i18n("Zoom %1%").tqarg(zoom() * 100, 0, 'f', 0));
+ m_statusBarZoomLabel->setText(i18n("Zoom %1%").arg(zoom() * 100, 0, 'f', 0));
}
- m_statusBarZoomLabel->setMaximumWidth(m_statusBarZoomLabel->fontMetrics().width(i18n("Zoom %1%").tqarg("0.8888 ")));
+ m_statusBarZoomLabel->setMaximumWidth(m_statusBarZoomLabel->fontMetrics().width(i18n("Zoom %1%").arg("0.8888 ")));
}
void KisView::updateStatusBarSelectionLabel()
@@ -513,7 +513,7 @@ void KisView::updateStatusBarSelectionLabel()
if (dev) {
if (dev->hasSelection()) {
TQRect r = dev->selection()->selectedExactRect();
- m_statusBarSelectionLabel->setText( i18n("Selection Active: x = %1 y = %2 width = %3 height = %4").tqarg(r.x()).tqarg(r.y()).tqarg( r.width()).tqarg( r.height()));
+ m_statusBarSelectionLabel->setText( i18n("Selection Active: x = %1 y = %2 width = %3 height = %4").arg(r.x()).arg(r.y()).arg( r.width()).arg( r.height()));
return;
}
}
@@ -682,7 +682,7 @@ void KisView::setupActions()
new KAction(i18n("Edit Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditPalette()),
actionCollection(), "edit_palette");
// XXX: This triggers a tqrepaint of the image, but way too early
//showRuler();
}
@@ -858,7 +858,7 @@ void KisView::resizeEvent(TQResizeEvent *)
if (!m_canvasPixmap.isNull() && !exposedRegion.isEmpty()) {
- TQMemArray<TQRect> rects = exposedRegion.tqrects();
+ TQMemArray<TQRect> rects = exposedRegion.rects();
for (unsigned int i = 0; i < rects.count(); i++) {
TQRect r = rects[i];
@@ -958,7 +958,7 @@ void KisView::updateTQPaintDeviceCanvas(const TQRect& imageRect)
TQRegion rg(vr);
rg -= TQRegion(windowToView(TQRect(0, 0, img->width(), img->height())));
- TQMemArray<TQRect> rects = rg.tqrects();
+ TQMemArray<TQRect> rects = rg.rects();
for (unsigned int i = 0; i < rects.count(); i++) {
TQRect er = rects[i];
@@ -1025,7 +1025,7 @@ void KisView::paintTQPaintDeviceView(const TQRegion& canvasRegion)
Q_ASSERT(m_canvas->TQPaintDeviceWidget() != 0);
if (m_canvas->TQPaintDeviceWidget() != 0 && !m_canvasPixmap.isNull()) {
- TQMemArray<TQRect> rects = canvasRegion.tqrects();
+ TQMemArray<TQRect> rects = canvasRegion.rects();
for (unsigned int i = 0; i < rects.count(); i++) {
TQRect r = rects[i];
@@ -1226,7 +1226,7 @@ void KisView::updateCanvas(const TQRect& imageRect)
} else {
updateTQPaintDeviceCanvas(imageRect);
//m_canvas->update(windowToView(imageRect));
- m_canvas->tqrepaint(windowToView(imageRect));
+ m_canvas->repaint(windowToView(imageRect));
}
}
@@ -1241,7 +1241,7 @@ void KisView::refreshKisCanvas()
updateCanvas(imageRect);
// Enable this if updateCanvas does an m_canvas->update()
- //m_canvas->tqrepaint();
+ //m_canvas->repaint();
}
void KisView::selectionDisplayToggled(bool displaySelection)
@@ -2965,7 +2965,7 @@ void KisView::layerDuplicate()
return;
KisLayerSP dup = active->clone();
- dup->setName(i18n("Duplicate of '%1'").tqarg(active->name()));
+ dup->setName(i18n("Duplicate of '%1'").arg(active->name()));
img->addLayer(dup, active->parent().data(), active);
if (dup) {
img->activate( dup );
@@ -3086,7 +3086,7 @@ void KisView::scrollH(int value)
bitBlt(&m_canvasPixmap, xShift, 0, &m_canvasPixmap, 0, 0, m_canvasPixmap.width() - xShift, m_canvasPixmap.height());
updateTQPaintDeviceCanvas(viewToWindow(drawRect));
- m_canvas->tqrepaint();
+ m_canvas->repaint();
}
} else if (xShift < 0) {
@@ -3098,7 +3098,7 @@ void KisView::scrollH(int value)
bitBlt(&m_canvasPixmap, 0, 0, &m_canvasPixmap, -xShift, 0, m_canvasPixmap.width() + xShift, m_canvasPixmap.height());
updateTQPaintDeviceCanvas(viewToWindow(drawRect));
- m_canvas->tqrepaint();
+ m_canvas->repaint();
}
}
if (m_oldTool) {
@@ -3131,7 +3131,7 @@ void KisView::scrollV(int value)
bitBlt(&m_canvasPixmap, 0, yShift, &m_canvasPixmap, 0, 0, m_canvasPixmap.width(), m_canvasPixmap.height() - yShift);
updateTQPaintDeviceCanvas(viewToWindow(drawRect));
- m_canvas->tqrepaint();
+ m_canvas->repaint();
}
} else if (yShift < 0) {
@@ -3143,7 +3143,7 @@ void KisView::scrollV(int value)
bitBlt(&m_canvasPixmap, 0, 0, &m_canvasPixmap, 0, -yShift, m_canvasPixmap.width(), m_canvasPixmap.height() + yShift);
updateTQPaintDeviceCanvas(viewToWindow(drawRect));
- m_canvas->tqrepaint();
+ m_canvas->repaint();
}
}
if (m_oldTool) {
@@ -3470,7 +3470,7 @@ bool KisView::eventFilter(TQObject *o, TQEvent *e)
// We ignore device change due to mouse events for a short duration
// after a tablet event, since these are almost certainly mouse events
- // sent to tqreceivers that don't accept the tablet event.
+ // sent to receivers that don't accept the tablet event.
m_tabletEventTimer.start();
break;
}
@@ -3544,7 +3544,7 @@ bool KisView::eventFilter(TQObject *o, TQEvent *e)
mgr = img->guides();
if (e->type() == TQEvent::MouseMove && (me->state() & Qt::LeftButton)) {
- bool flag = tqgeometry().contains(pt);
+ bool flag = geometry().contains(pt);
KisGuideSP gd;
if (m_currentGuide == 0 && flag) {
@@ -682,7 +682,7 @@ void KisView::setupActions()
new KAction(i18n("Edit Palette..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditPalette()),
actionCollection(), "edit_palette");
- // XXX: This triggers a tqrepaint of the image, but way too early
+ // XXX: This triggers a repaint of the image, but way too early
//showRuler();
}